@@ -15,6 +15,7 @@
 
 from __future__ import division, absolute_import
 
+import ctypes.util
 import functools
 import platform
 import six
@@ -26,15 +27,18 @@ try:
 except ImportError:
     from xcffib.ffi_build import ffi
 
-soname = "libxcb.so.1"
 if platform.system() == "Darwin":
     soname = "libxcb.dylib"
 elif platform.system() == "Windows":
     soname = "libxcb.dll"
+else:
+    soname = ctypes.util.find_library("xcb")
+    if soname is None:
+        soname = "libxcb.so"
 lib = ffi.dlopen(soname)
 
-__xcb_proto_version__ = "1.11"
-__version__ = "0.5.1"
+__xcb_proto_version__ = "1.13"
+__version__ = "0.8.0"
 
 X_PROTOCOL = lib.X_PROTOCOL
 X_PROTOCOL_REVISION = lib.X_PROTOCOL_REVISION
@@ -247,7 +251,7 @@ def _add_ext(key, value, events, errors):
 
 class ExtensionKey(object):
 
-    """ This definitely isn't needed, but we keep it around for compatibilty
+    """ This definitely isn't needed, but we keep it around for compatibility
     with xpyb.
     """
 
@@ -297,6 +301,12 @@ class Protobj(object):
             self.bufsize = unpacker.known_max
 
 
+class Buffer(Protobj):
+    def __init__(self, unpacker):
+        Protobj.__init__(self, unpacker)
+        self.buf = unpacker.buf
+
+
 class Struct(Protobj):
     pass
 
@@ -405,7 +415,7 @@ class List(Protobj):
         old = unpacker.offset
 
         if isinstance(typ, str):
-            self.list = list(unpacker.unpack(typ * count))
+            self.list = list(unpacker.unpack("%d%s" % (count, typ)))
         elif count is not None:
             for _ in range(count):
                 item = typ(unpacker)
@@ -418,6 +428,8 @@ class List(Protobj):
 
         self.bufsize = unpacker.offset - old
 
+        self.raw = bytes(unpacker.buf[old:old + self.bufsize])
+
         assert count is None or count == len(self.list)
 
     def __str__(self):
@@ -449,10 +461,10 @@ class List(Protobj):
 
     def to_atoms(self):
         """ A helper for converting a List of chars to an array of atoms """
-        return struct.unpack("<" + "I" * (len(self) // 4), b''.join(self))
+        return struct.unpack("<" + "%dI" % (len(self) // 4), b''.join(self))
 
     def buf(self):
-        return b''.join(self.list)
+        return self.raw
 
     @classmethod
     def synthetic(cls, list=None):
@@ -767,7 +779,7 @@ def pack_list(from_, pack_type):
             from_ = [six.int2byte(b) for i in from_ for b in to_bytes(i)]
 
     if isinstance(pack_type, six.string_types):
-        return struct.pack("=" + pack_type * len(from_), *from_)
+        return struct.pack("=%d%s" % (len(from_), pack_type), *from_)
     else:
         buf = six.BytesIO()
         for item in from_:
